@@ -22,6 +22,7 @@ from .utils import (
     is_paddle_available,
     is_paddlenlp_available,
     is_unidecode_available,
+    is_fastdeploy_available,
 )
 from .version import VERSION
 
@@ -29,9 +30,11 @@ __version__ = VERSION
 
 from .configuration_utils import ConfigMixin
 from .onnx_utils import OnnxRuntimeModel
+from .fastdeploy_utils import FastDeployRuntimeModel
 from .utils import logging
 
 if is_paddle_available():
+    from .initializer import *
     from .modeling_utils import ModelMixin
     from .models import AutoencoderKL, UNet2DConditionModel, UNet2DModel, VQModel
     from .optimization import (
@@ -49,6 +52,7 @@ if is_paddle_available():
         EulerAncestralDiscreteScheduler,
         DDIMScheduler,
         DDPMScheduler,
+        DPMSolverMultistepScheduler,
         KarrasVeScheduler,
         PNDMScheduler,
         SchedulerMixin,
@@ -81,3 +85,13 @@ if is_paddle_available() and is_paddlenlp_available() and is_onnx_available():
     )
 else:
     from .utils.dummy_paddle_and_paddlenlp_and_onnx_objects import *  # noqa F403
+
+if is_paddle_available() and is_paddlenlp_available(
+) and is_fastdeploy_available():
+    from .pipelines import (
+        FastDeployStableDiffusionImg2ImgPipeline,
+        FastDeployStableDiffusionInpaintPipeline,
+        FastDeployStableDiffusionPipeline,
+    )
+else:
+    from .utils.dummy_paddle_and_paddlenlp_and_fastdeploy_objects import *  # noqa F403
